@@ -7,7 +7,7 @@ use utf8;
 use Template::Reverse::Part;
 use Algorithm::Diff qw(sdiff);
 use Scalar::Util qw(blessed);
-our $VERSION = '0.142'; # VERSION
+our $VERSION = '0.143'; # VERSION
 
 
 has 'sidelen' => (
@@ -115,7 +115,7 @@ Template::Reverse - A template generator getting different parts between pair of
 
 =head1 VERSION
 
-version 0.142
+version 0.143
 
 =head1 SYNOPSIS
 
@@ -155,10 +155,9 @@ more
     my $value = $ext->extract($templates->[1], $str3);
     print Dumper($value); # output : {'value'=>'a richest man'}
 
-
     # extract with Regexp
     my $regexp_conv = Template::Reverse::Converter::Regexp->new;
-    my $regexp_list = $regexp_conv->Convert($parts); # equals to ['I am [% value %] and ',' and [% value %]']
+    my $regexp_list = $regexp_conv->Convert($parts); 
 
     my $str3 = "I am king of the world and a richest man";
      
@@ -172,7 +171,7 @@ more
     # When you need to get regexp as string.
     use re regexp_pattern;
     my($pat,$flag) = regexp_pattern( $regexp_list->[0] );
-    print $pat; # Not to use $flag, set flags in pat like '(?i)...'.
+    print $pat; # Regexp generates regexps without flags. So you do not need to use $flag.
 
 =head1 DESCRIPTION
 
@@ -257,6 +256,7 @@ Returned arrayRef is list of changable parts.
 =item *
 
 L<Template::Extract>
+L<Parse::Token::Lite>
 
 =head1 SOURCE
 
